<?php
/**
 * Dashboard class.
 *
 * @category   apps
 * @package    Gateway Management
 * @subpackage libraries
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2020 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\gateway_management;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('base');
clearos_load_language('gateway_management');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

// Classes
//--------

use \clearos\apps\gateway_management\Configurator;
use \clearos\apps\gateway_management\Firewall;
use \clearos\apps\gateway_management\Network;
use \clearos\apps\gateway_management\Service;

use \clearos\apps\base\Engine;
use \clearos\apps\base\File;
use \clearos\apps\base\Folder;
use \clearos\apps\base\Shell;
use \clearos\apps\clearcenter\Rest;
use \clearos\apps\dhcp\Dnsmasq;
use \clearos\apps\marketplace\Marketplace as Marketplace;
use \clearos\apps\network\Hosts;
use \clearos\apps\network\Iface;
use \clearos\apps\network\Network_Utils;
use \clearos\apps\network\Resolver;
use \clearos\apps\network\Routes;
use \clearos\apps\tasks\Cron;

clearos_load_library('gateway_management/Configurator');
clearos_load_library('gateway_management/Firewall');
clearos_load_library('gateway_management/Network');
clearos_load_library('gateway_management/Service');

clearos_load_library('base/Engine');
clearos_load_library('base/File');
clearos_load_library('base/Folder');
clearos_load_library('base/Shell');
clearos_load_library('clearcenter/Rest');
clearos_load_library('dhcp/Dnsmasq');
clearos_load_library('marketplace/Marketplace');
clearos_load_library('network/Hosts');
clearos_load_library('network/Iface');
clearos_load_library('network/Network_Utils');
clearos_load_library('network/Resolver');
clearos_load_library('network/Routes');
clearos_load_library('tasks/Cron');

// Exceptions
//-----------
use \clearos\apps\base\Engine_Exception;
use \clearos\apps\base\Not_Found_Exception;
use \clearos\apps\base\Validation_Exception as Validation_Exception;

clearos_load_library('base/Engine_Exception');


///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

class Dashboard extends Engine
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    // Labels
    const API_URL             = 'https://dashboard.contentfilter.net/';

    ///////////////////////////////////////////////////////////////////////////////
    // V A R I A B L E S
    ///////////////////////////////////////////////////////////////////////////////

    protected $dir = ''; // unused

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Dashboard constructor.
     */
    public function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);
    }

    /**
     * Return the API url.
     *
     * @return string
     */
    public function api_url()
    {
        return self::API_URL;
    }

    /**
     * Get marketplace info.
     *
     * @return string
     */
    public function get_marketplace_info()
    {
        clearos_profile(__METHOD__, __LINE__);

        $marketplace = new Marketplace();
        $data = $marketplace->get_sdn_info();

        return $data;
    }

    /**
     * Register.
     *
     * @return array
     */
    public function register()
    {
        clearos_profile(__METHOD__, __LINE__);

        $service = new Service();

        // get the post data
        $marketplace = $this->get_marketplace_info();
        $info = json_decode($marketplace);

        $post = array(
            'email' => $info->email,
            'name' => $info->username,
            'billing_id' => (string) $info->username,
            'billing_service' => 'clearos',
            'network_name' => $info->device_name,
            'box_id' => $service->get_box_id(),
            'device_billing_id' => (string) $info->device_id,
        );

        $post = json_encode($post);

        $url = self::API_URL . 'api/v2/partner/clients';

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);

        curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-type: application/json"));
        curl_setopt($ch, CURLOPT_POSTFIELDS, $post);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HEADER, 1);
        curl_setopt($ch, CURLOPT_TIMEOUT, 60);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        $response = curl_exec($ch);
        $h_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
        curl_close($ch);

        list($headers, $body) = explode("\r\n\r\n", $response, 2);
        preg_match('/^HTTP\/.*$/m', $headers, $status);

        return array(
            'header' => $status[0],
            'body' => $body,
        );
    }

    /**
     * Returns the ClearOS subscription status.
     *
     * @return string ClearOS subscription status
     */
    public function get_subscription_status()
    {
        clearos_profile(__METHOD__, __LINE__);

        $rest = new Rest();

        $box_id = $this->get_box_id();

        if (!$box_id) {

            $array = array(
                'status' => -1
            );

        } else {

            $extras['boxid'] = $box_id;

            $result = $rest->request('dt_mgr', 'activate', $extras);
            $this->subscription_status = $result;

            $array = json_decode($result, TRUE);
            $array['short_msg'] = $this->lang('sub_status_'.$array['code']);

        }

        $result = json_encode($array);

        echo $result;
        exit;
    }

    ///////////////////////////////////////////////////////////////////////////////
    // P R I V A T E   M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

}
