<?php
/**
 * Utility class.
 *
 * @category   apps
 * @package    Gateway Management
 * @subpackage libraries
 * @author     ADAMnetworks <support@adamnet.works>
 * @copyright  2015-2019 ADAMnetworks
 * @license    All rights reserved
 * @link       https://adamnet.works
 */

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\gateway_management;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

// Classes
//--------

use \clearos\apps\base\Engine;
use \clearos\apps\base\Shell;

clearos_load_library('base/Engine');
clearos_load_library('base/Shell');

// Exceptions
//-----------
use \clearos\apps\base\Engine_Exception;
use \clearos\apps\base\Not_Found_Exception;
use \clearos\apps\base\Validation_Exception as Validation_Exception;

clearos_load_library('base/Engine_Exception');


///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

class Util extends Engine
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    const WHICH_PATH          = '/usr/bin/which';

    ///////////////////////////////////////////////////////////////////////////////
    // V A R I A B L E S
    ///////////////////////////////////////////////////////////////////////////////

    protected $config = NULL;
    protected $issues = array();
    protected $proxy_supported = NULL;
    protected $warnings = array();

    // Initialized by constructor
    protected $dir = '';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Util constructor.
     */
    public function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);

        $this->dir = basename(dirname(__DIR__));
    }

    /**
     * Get the directory name
     *
     * @return string
     */
    public function get_dir()
    {
        clearos_profile(__METHOD__, __LINE__);

        return $this->dir;
    }


    /**
     * Return text in proper translation
     *
     * @return string
     */
    public function lang($key) {
        return lang($this->dir . '_' . $key);
    }

    /**
     * Find the path of a command.
     *
     * @return string path
     */
    public function get_path($cmd)
    {
        clearos_profile(__METHOD__, __LINE__);

        // Cache the value.
        $path = $cmd . '_path';
        if (!isset($this->$path)) {
            // Get the path.
            $shell = new Shell();
            $shell->execute(self::WHICH_PATH, "--skip-alias $cmd");
            $this->$path = $shell->get_first_output_line();
        }

        return $this->$path;
    }

}
